% 
% Written by:
% -- 
% John L. Weatherwax                2006-08-28
% 
% email: wax@alum.mit.edu
% 
% Please send comments and especially bug reports to the
% above email address.
% 
%-----

clc; close all; clear; 

rand('seed',0); randn('seed',0);

% do the example of randomly distributed eigenvalues:
% 
n = 50; 

A  = gen_A_mat_uniform(n); 
b  = zeros(n,1);
x0 = ones(n,1); 

allANorms = [];
for mni=1:n,
  [x,niter,rtr] = cgsolve( A, b, x0, mni, 1.e-9 ); 
  aNorm         = log( 0.5 * x' * A * x ); 
  allANorms = [ allANorms, aNorm ]; 
end

uh = plot( 1:n, allANorms, '-ob' );
%axis( [0,20,min(allANorms),max(allANorms)] ); 
xlabel('iteration number'); ylabel('log(||x-x^*||_A^2) e.g. distance from true solution'); 

% do the example of "clustered" eigenvalues: 
% 
m = 20; % number of eigenvalues to put in the second cluster 

A  = gen_A_mat_clustered(n,2);
b  = zeros(n,1);
x0 = ones(n,1); 

allANorms = [];
for mni=1:n,
  [x,niter,rtr] = cgsolve( A, b, x0, mni, 1.e-9 ); 
  aNorm         = log( 0.5 * x' * A * x ); 
  allANorms = [ allANorms, aNorm ]; 
end

hold on; 
ch = plot( 1:n, allANorms, '-or' );
%axis( [0,20,min(allANorms),max(allANorms)] ); 
xlabel('iteration number'); ylabel('log(||x-x^*||_A^2) e.g. distance from true solution'); 

legend( [uh,ch], 'uniform eigenvalues', 'clustered eigenvalues' );

